@@ -7,11 +7,11 @@
 // more info and bugs-report:  github.com/raysan5/raygui                        //
 // feedback and support:       ray[at]raylibtech.com                            //
 //                                                                              //
-// Copyright (c) 2020-2024 raylib technologies (@raylibtech)                    //
+// Copyright (c) 2020-2025 raylib technologies (@raylibtech)                    //
 //                                                                              //
 //////////////////////////////////////////////////////////////////////////////////
 
-#define AMBER_STYLE_PROPS_COUNT  16
+#define AMBER_STYLE_PROPS_COUNT  18
 
 // Custom style name: Amber
 static const GuiStyleProp amberStyleProps[AMBER_STYLE_PROPS_COUNT] = {
@@ -23,7 +23,7 @@ static const GuiStyleProp amberStyleProps[AMBER_STYLE_PROPS_COUNT] = {
     { 0, 5, (int)0xffffffff },    // DEFAULT_TEXT_COLOR_FOCUSED 
     { 0, 6, (int)0xf1cf9dff },    // DEFAULT_BORDER_COLOR_PRESSED 
     { 0, 7, (int)0xf39333ff },    // DEFAULT_BASE_COLOR_PRESSED 
-    { 0, 8, (int)0x282020ff },    // DEFAULT_TEXT_COLOR_PRESSED 
+    { 0, 8, (int)0x191410ff },    // DEFAULT_TEXT_COLOR_PRESSED 
     { 0, 9, (int)0x6a6a6aff },    // DEFAULT_BORDER_COLOR_DISABLED 
     { 0, 10, (int)0x818181ff },    // DEFAULT_BASE_COLOR_DISABLED 
     { 0, 11, (int)0x606060ff },    // DEFAULT_TEXT_COLOR_DISABLED 
@@ -31,6 +31,8 @@ static const GuiStyleProp amberStyleProps[AMBER_STYLE_PROPS_COUNT] = {
     { 0, 18, (int)0xef922aff },    // DEFAULT_LINE_COLOR 
     { 0, 19, (int)0x333333ff },    // DEFAULT_BACKGROUND_COLOR 
     { 0, 20, (int)0x00000018 },    // DEFAULT_TEXT_LINE_SPACING 
+    { 1, 8, (int)0xe7e0d4ff },    // LABEL_TEXT_COLOR_PRESSED 
+    { 4, 8, (int)0xf1cf9dff },    // SLIDER_TEXT_COLOR_PRESSED 
 };
 
 // WARNING: This style uses a custom font: "hello-world.ttf" (size: 16, spacing: 1)
