@@ -99,7 +99,7 @@ data MusicContextType
   | MusicAudioQOA
   | MusicModuleXM
   | MusicModuleMOD
-  deriving (Eq, Show, Enum)
+  deriving (Eq, Show, Read, Enum)
 
 instance Storable MusicContextType where
   sizeOf _ = 4
@@ -112,7 +112,7 @@ instance Storable MusicContextType where
 data AudioBufferUsage
   = AudioBufferUsageStatic
   | AudioBufferUsageStream
-  deriving (Eq, Show, Enum)
+  deriving (Eq, Show, Read, Enum)
 
 instance Storable AudioBufferUsage where
   sizeOf _ = 4
@@ -133,7 +133,7 @@ data Wave = Wave
     wave'channels :: Integer,
     wave'data :: [Int]
   }
-  deriving (Eq, Show)
+  deriving (Eq, Show, Read)
 
 instance Storable Wave where
   sizeOf _ = 24
@@ -577,4 +577,4 @@ p'music'ctxData = (`plusPtr` 48)
 
 type AudioCallback = Ptr () -> Integer -> IO ()
 
-type C'AudioCallback = FunPtr (Ptr () -> CUInt -> IO ())
\ No newline at end of file
+type C'AudioCallback = FunPtr (Ptr () -> CUInt -> IO ())
